=begin comment

BMLT

BMLT Admin API Documentation

The version of the OpenAPI document: 1.0.0

Generated by: https://openapi-generator.tech

=end comment

=cut

#
# NOTE: This class is auto generated by the OpenAPI Generator
# Please update the test cases below to test the model.
# Ref: https://openapi-generator.tech
#
use Test::More tests => 2;
use Test::Exception;

use lib 'lib';
use strict;
use warnings;


use_ok('BmltClient::Object::AuthenticationError');

# uncomment below and update the test
#my $instance = BmltClient::Object::AuthenticationError->new();
#
#isa_ok($instance, 'BmltClient::Object::AuthenticationError');

