=begin comment

BMLT

BMLT Admin API Documentation

The version of the OpenAPI document: 1.0.0

Generated by: https://openapi-generator.tech

=end comment

=cut

#
# NOTE: This class is auto generated by OpenAPI Generator
# Please update the test cases below to test the API endpoints.
# Ref: https://openapi-generator.tech
#
use Test::More tests => 1; #TODO update number of test cases
use Test::Exception;

use lib 'lib';
use strict;
use warnings;

use_ok('BmltClient::RootServerApi');

my $api = BmltClient::RootServerApi->new();
isa_ok($api, 'BmltClient::RootServerApi');

#
# auth_logout test
#
# uncomment below and update the test
#my $auth_logout_result = $api->auth_logout();

#
# auth_refresh test
#
# uncomment below and update the test
#my $auth_refresh_result = $api->auth_refresh();

#
# auth_token test
#
# uncomment below and update the test
#my $auth_token_token_credentials = undef; # replace NULL with a proper value
#my $auth_token_result = $api->auth_token(token_credentials => $auth_token_token_credentials);

#
# create_format test
#
# uncomment below and update the test
#my $create_format_format_create = undef; # replace NULL with a proper value
#my $create_format_result = $api->create_format(format_create => $create_format_format_create);

#
# create_meeting test
#
# uncomment below and update the test
#my $create_meeting_meeting_create = undef; # replace NULL with a proper value
#my $create_meeting_result = $api->create_meeting(meeting_create => $create_meeting_meeting_create);

#
# create_service_body test
#
# uncomment below and update the test
#my $create_service_body_service_body_create = undef; # replace NULL with a proper value
#my $create_service_body_result = $api->create_service_body(service_body_create => $create_service_body_service_body_create);

#
# create_user test
#
# uncomment below and update the test
#my $create_user_user_create = undef; # replace NULL with a proper value
#my $create_user_result = $api->create_user(user_create => $create_user_user_create);

#
# delete_format test
#
# uncomment below and update the test
#my $delete_format_format_id = undef; # replace NULL with a proper value
#my $delete_format_result = $api->delete_format(format_id => $delete_format_format_id);

#
# delete_meeting test
#
# uncomment below and update the test
#my $delete_meeting_meeting_id = undef; # replace NULL with a proper value
#my $delete_meeting_result = $api->delete_meeting(meeting_id => $delete_meeting_meeting_id);

#
# delete_service_body test
#
# uncomment below and update the test
#my $delete_service_body_service_body_id = undef; # replace NULL with a proper value
#my $delete_service_body_result = $api->delete_service_body(service_body_id => $delete_service_body_service_body_id);

#
# delete_user test
#
# uncomment below and update the test
#my $delete_user_user_id = undef; # replace NULL with a proper value
#my $delete_user_result = $api->delete_user(user_id => $delete_user_user_id);

#
# get_format test
#
# uncomment below and update the test
#my $get_format_format_id = undef; # replace NULL with a proper value
#my $get_format_result = $api->get_format(format_id => $get_format_format_id);

#
# get_formats test
#
# uncomment below and update the test
#my $get_formats_result = $api->get_formats();

#
# get_meeting test
#
# uncomment below and update the test
#my $get_meeting_meeting_id = undef; # replace NULL with a proper value
#my $get_meeting_result = $api->get_meeting(meeting_id => $get_meeting_meeting_id);

#
# get_meetings test
#
# uncomment below and update the test
#my $get_meetings_meeting_ids = undef; # replace NULL with a proper value
#my $get_meetings_days = undef; # replace NULL with a proper value
#my $get_meetings_service_body_ids = undef; # replace NULL with a proper value
#my $get_meetings_search_string = undef; # replace NULL with a proper value
#my $get_meetings_result = $api->get_meetings(meeting_ids => $get_meetings_meeting_ids, days => $get_meetings_days, service_body_ids => $get_meetings_service_body_ids, search_string => $get_meetings_search_string);

#
# get_service_bodies test
#
# uncomment below and update the test
#my $get_service_bodies_result = $api->get_service_bodies();

#
# get_service_body test
#
# uncomment below and update the test
#my $get_service_body_service_body_id = undef; # replace NULL with a proper value
#my $get_service_body_result = $api->get_service_body(service_body_id => $get_service_body_service_body_id);

#
# get_user test
#
# uncomment below and update the test
#my $get_user_user_id = undef; # replace NULL with a proper value
#my $get_user_result = $api->get_user(user_id => $get_user_user_id);

#
# get_users test
#
# uncomment below and update the test
#my $get_users_result = $api->get_users();

#
# partial_update_user test
#
# uncomment below and update the test
#my $partial_update_user_user_id = undef; # replace NULL with a proper value
#my $partial_update_user_user_partial_update = undef; # replace NULL with a proper value
#my $partial_update_user_result = $api->partial_update_user(user_id => $partial_update_user_user_id, user_partial_update => $partial_update_user_user_partial_update);

#
# patch_format test
#
# uncomment below and update the test
#my $patch_format_format_id = undef; # replace NULL with a proper value
#my $patch_format_format_partial_update = undef; # replace NULL with a proper value
#my $patch_format_result = $api->patch_format(format_id => $patch_format_format_id, format_partial_update => $patch_format_format_partial_update);

#
# patch_meeting test
#
# uncomment below and update the test
#my $patch_meeting_meeting_id = undef; # replace NULL with a proper value
#my $patch_meeting_meeting_partial_update = undef; # replace NULL with a proper value
#my $patch_meeting_result = $api->patch_meeting(meeting_id => $patch_meeting_meeting_id, meeting_partial_update => $patch_meeting_meeting_partial_update);

#
# patch_service_body test
#
# uncomment below and update the test
#my $patch_service_body_service_body_id = undef; # replace NULL with a proper value
#my $patch_service_body_service_body_partial_update = undef; # replace NULL with a proper value
#my $patch_service_body_result = $api->patch_service_body(service_body_id => $patch_service_body_service_body_id, service_body_partial_update => $patch_service_body_service_body_partial_update);

#
# update_format test
#
# uncomment below and update the test
#my $update_format_format_id = undef; # replace NULL with a proper value
#my $update_format_format_update = undef; # replace NULL with a proper value
#my $update_format_result = $api->update_format(format_id => $update_format_format_id, format_update => $update_format_format_update);

#
# update_meeting test
#
# uncomment below and update the test
#my $update_meeting_meeting_id = undef; # replace NULL with a proper value
#my $update_meeting_meeting_update = undef; # replace NULL with a proper value
#my $update_meeting_result = $api->update_meeting(meeting_id => $update_meeting_meeting_id, meeting_update => $update_meeting_meeting_update);

#
# update_service_body test
#
# uncomment below and update the test
#my $update_service_body_service_body_id = undef; # replace NULL with a proper value
#my $update_service_body_service_body_update = undef; # replace NULL with a proper value
#my $update_service_body_result = $api->update_service_body(service_body_id => $update_service_body_service_body_id, service_body_update => $update_service_body_service_body_update);

#
# update_user test
#
# uncomment below and update the test
#my $update_user_user_id = undef; # replace NULL with a proper value
#my $update_user_user_update = undef; # replace NULL with a proper value
#my $update_user_result = $api->update_user(user_id => $update_user_user_id, user_update => $update_user_user_update);

